.. currentmodule:: fastdla

=====================
Eigenspace projection
=====================

Eigenspace extraction functions.

.. autosummary::
   :toctree: ../generated
   :recursive:

   get_eigenspace
